# Changelog

## 0.1.0-alpha.9 (2025-08-27)

Full Changelog: [v0.1.0-alpha.8...v0.1.0-alpha.9](https://github.com/bluehive-health/bluehive-sdk-python/compare/v0.1.0-alpha.8...v0.1.0-alpha.9)

### Bug Fixes

* avoid newer type syntax ([3eb192a](https://github.com/bluehive-health/bluehive-sdk-python/commit/3eb192a9c2236839c9df644d481f16c9080bd472))


### Chores

* **internal:** change ci workflow machines ([cc6b943](https://github.com/bluehive-health/bluehive-sdk-python/commit/cc6b94314dfe2ff1709d61f1350967e08af858a6))
* **internal:** update pyright exclude list ([ad0c5d7](https://github.com/bluehive-health/bluehive-sdk-python/commit/ad0c5d726b5e71b3def2cdde214f11cd73f84c03))
* update github action ([9ada64d](https://github.com/bluehive-health/bluehive-sdk-python/commit/9ada64d8535118deb501a45cfbea5ea3ed9714dd))

## 0.1.0-alpha.8 (2025-08-13)

Full Changelog: [v0.1.0-alpha.7...v0.1.0-alpha.8](https://github.com/bluehive-health/bluehive-sdk-python/compare/v0.1.0-alpha.7...v0.1.0-alpha.8)

### Chores

* **internal:** codegen related update ([6f04aff](https://github.com/bluehive-health/bluehive-sdk-python/commit/6f04afff1ae3b0d1f7d984c591af132408d433b8))

## 0.1.0-alpha.7 (2025-08-09)

Full Changelog: [v0.1.0-alpha.6...v0.1.0-alpha.7](https://github.com/bluehive-health/bluehive-sdk-python/compare/v0.1.0-alpha.6...v0.1.0-alpha.7)

### Features

* **client:** support file upload requests ([97b5965](https://github.com/bluehive-health/bluehive-sdk-python/commit/97b59652bb608e71d907eac2edf2e31e9971f691))


### Chores

* **internal:** fix ruff target version ([14647cc](https://github.com/bluehive-health/bluehive-sdk-python/commit/14647cc4fffa3f022dded15d158a84f34dc433b9))
* **project:** add settings file for vscode ([c6ce060](https://github.com/bluehive-health/bluehive-sdk-python/commit/c6ce06020743ba8cf316a44f0694e61710b61edb))
* update @stainless-api/prism-cli to v5.15.0 ([85b2246](https://github.com/bluehive-health/bluehive-sdk-python/commit/85b2246ab0b26cc8efb0756893177dafa517b86a))

## 0.1.0-alpha.6 (2025-07-23)

Full Changelog: [v0.1.0-alpha.5...v0.1.0-alpha.6](https://github.com/bluehive-health/bluehive-sdk-python/compare/v0.1.0-alpha.5...v0.1.0-alpha.6)

### Bug Fixes

* **parsing:** parse extra field types ([cbedac0](https://github.com/bluehive-health/bluehive-sdk-python/commit/cbedac003fe3de81d86cf69dfc55badf63a8caa4))

## 0.1.0-alpha.5 (2025-07-22)

Full Changelog: [v0.1.0-alpha.4...v0.1.0-alpha.5](https://github.com/bluehive-health/bluehive-sdk-python/compare/v0.1.0-alpha.4...v0.1.0-alpha.5)

### Features

* clean up environment call outs ([3277aa1](https://github.com/bluehive-health/bluehive-sdk-python/commit/3277aa128c028148a893af9e23ac74ac0349654a))


### Bug Fixes

* **parsing:** ignore empty metadata ([937f49a](https://github.com/bluehive-health/bluehive-sdk-python/commit/937f49a01c0c6e7ac45880c16f1006b74bfb6133))

## 0.1.0-alpha.4 (2025-07-12)

Full Changelog: [v0.1.0-alpha.3...v0.1.0-alpha.4](https://github.com/bluehive-health/bluehive-sdk-python/compare/v0.1.0-alpha.3...v0.1.0-alpha.4)

### Bug Fixes

* **client:** don't send Content-Type header on GET requests ([2c2bbb9](https://github.com/bluehive-health/bluehive-sdk-python/commit/2c2bbb99f7774aeb7eaaf955c188819794376adc))


### Chores

* **readme:** fix version rendering on pypi ([933fd60](https://github.com/bluehive-health/bluehive-sdk-python/commit/933fd60ff623cb82bc3017b5180c73fea804b72a))

## 0.1.0-alpha.3 (2025-07-10)

Full Changelog: [v0.1.0-alpha.2...v0.1.0-alpha.3](https://github.com/bluehive-health/bluehive-sdk-python/compare/v0.1.0-alpha.2...v0.1.0-alpha.3)

### Bug Fixes

* **parsing:** correctly handle nested discriminated unions ([15d178d](https://github.com/bluehive-health/bluehive-sdk-python/commit/15d178d4a1ca566cff253150d6ee4e0ea55d9e2b))

## 0.1.0-alpha.2 (2025-07-09)

Full Changelog: [v0.1.0-alpha.1...v0.1.0-alpha.2](https://github.com/bluehive-health/bluehive-sdk-python/compare/v0.1.0-alpha.1...v0.1.0-alpha.2)

### Chores

* **internal:** bump pinned h11 dep ([77b8495](https://github.com/bluehive-health/bluehive-sdk-python/commit/77b84958a99fea04743c4aaf300731dedc61da3a))
* **package:** mark python 3.13 as supported ([e58a361](https://github.com/bluehive-health/bluehive-sdk-python/commit/e58a36108c35a42d3f665ac1972fe20d4afd7c54))

## 0.1.0-alpha.1 (2025-07-06)

Full Changelog: [v0.0.1-alpha.0...v0.1.0-alpha.1](https://github.com/bluehive-health/bluehive-sdk-python/compare/v0.0.1-alpha.0...v0.1.0-alpha.1)

### Features

* **api:** api update ([90448d7](https://github.com/bluehive-health/bluehive-sdk-python/commit/90448d76356b411bb678274c923ebf0d5d904218))


### Chores

* configure new SDK language ([d15c2c6](https://github.com/bluehive-health/bluehive-sdk-python/commit/d15c2c680ba6c46102b5b37fb3d9f31a66e5ba8d))
* update SDK settings ([4e5fa24](https://github.com/bluehive-health/bluehive-sdk-python/commit/4e5fa2407f9fcf01e7c25d040b4656246cb8d492))
* update SDK settings ([a9c06ff](https://github.com/bluehive-health/bluehive-sdk-python/commit/a9c06ff66ca3d06d5c6d1dc35458fbd387a5b7bc))
